#
# spec file for package libyami
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover   1
%define libname %{name}%{sover}
Name:           libxcam
Version:        1.0.0
Release:        1.40
Summary:        Image processing library for extended camera features and video analysis
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            https://github.com/01org/libxcam
Source0:        https://github.com/01org/libxcam/archive/release_%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  beignet-devel >= 1.2.0
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  libdrm-devel
BuildRequires:  ocl-icd-devel
BuildRequires:  opencl-headers
BuildRequires:  opencv-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(egl)
BuildRequires:  pkgconfig(glesv2)
BuildRequires:  pkgconfig(libdrm)
BuildRequires:  pkgconfig(libdrm_intel)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(libva-x11)
# Intel graphics hardware only available on these platforms
ExclusiveArch:  %{ix86} x86_64

%description
libXCam is a project for extended camera features and focus on image quality
improvement and video analysis. There are lots features supported in image
pre-processing, image post-processing and smart analysis. This library makes
GPU/CPU/ISP working together to improve image quality. OpenCL is used to improve
performance in different platforms.

%package -n %{libname}
Summary:        Image processing library for extended camera features and video analysis
Group:          System/Libraries

%description -n %{libname}
libXCam is a project for extended camera features and focus on image quality
improvement and video analysis. There are lots features supported in image
pre-processing, image post-processing and smart analysis. This library makes
GPU/CPU/ISP working together to improve image quality. OpenCL is used to improve
performance in different platforms.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q -n %{name}-release_%{version}

%build
autoreconf -fiv
%configure \
   --disable-static \
   --with-package-name="Libxcam (openSUSE)" \
   --with-package-origin="http://www.opensuse.org/" \
   --enable-drm \
   --disable-aiq \
   --enable-gst \
   --enable-libcl \
   --enable-opencv \
   --enable-capi \
   --enable-3alib \
   --enable-smartlib
make %{?_smp_mflags} V=1

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%defattr(-,root,root)
%doc README.md NOTICE COPYING
%{_libdir}/%{name}_capi.so.%{sover}*
%{_libdir}/%{name}_core.so.%{sover}*
%{_libdir}/%{name}_ocl.so.%{sover}*
%{_libdir}/gstreamer-1.0/libgstxcamsrc.so
%{_libdir}/gstreamer-1.0/libgstxcamfilter.so

%files devel
%defattr(-,root,root)
%{_includedir}/xcam
%{_libdir}/pkgconfig/libxcam.pc
%{_libdir}/libxcam_capi.so
%{_libdir}/libxcam_core.so
%{_libdir}/libxcam_ocl.so

%changelog
* Thu Oct 12 2017 jengelh@inai.de
- Update package summary.
* Mon Sep  4 2017 alarrosa@suse.com
- Update to version 1.0.0
  * 360 video stitching performance and quality improvement.
  - enable geometry map to improve performance.
  - quality tuned on different resolutions (1080P and 4K).
  - support CPU and OpenCL path in feature match.
  - enable lens shading correction based on fisheye image.
  * gyroscope-based video stabilization enabling.
  - enable gyroscope 3-DoF (orientation) assist video stabilization.
  - orientation (gyro) data should be measured by quaternion as the pose
    of target frame reference to base frame
  * CL framework refine.
  - enable CL argument template instead of member variables in kernel.
  - CL kernel support async mode.
  - image handler take over input/output buffer management from image kernel.
  * prepare libxcam debian package and fix most warnings.
- Remove fix-build-errors.diff which is no longer required
- Increased soname to 1
- The pkgconfig file has been renamed from xcam to libxcam
* Thu May 11 2017 alarrosa@suse.com
- Use --disable-aiq when configuring libxcam.
  AIQ/ia_imaging is an Intel proprietary 3A library.
* Tue May  9 2017 alarrosa@suse.com
- Initial release of libxcam
- Version 0.9.0
- Add fix-build-errors.diff to build correctly
